==> mdc-1.0-20250813.085035-1-sources.jar: com/digiwin/metadatacache/MdcApplicationParameter.java <==
package com.digiwin.metadatacache;

import com.digiwin.app.common.DWApplicationConfigUtils;
import com.digiwin.app.module.DWModulePropertiesUtils;
import com.digiwin.metadatacache.constant.MdcConstant;
import com.digiwin.metadatacache.util.MdcSpringContextUtil;
import org.springframework.beans.BeansException;
import org.springframework.beans.factory.InitializingBean;
import org.springframework.context.ApplicationContext;
import org.springframework.context.ApplicationContextAware;
import org.springframework.stereotype.Component;

/**
 * 配置获取
 */
@Component("mdcApplicationParameter")
public class MdcApplicationParameter implements InitializingBean, ApplicationContextAware {

    /**
     * the value keys in the property file
     */
    private static  String PK_MQ_PORT = DWModulePropertiesUtils.getProperty("processor", "mdc", "mq.port");
    private static  String PK_MQ_USERNAME = DWModulePropertiesUtils.getProperty("processor", "mdc", "mq.username");
    private static  String PK_MQ_PASSWORD = DWModulePropertiesUtils.getProperty("processor", "mdc", "mq.password");
    private static  String PK_MQ_HOST = DWModulePropertiesUtils.getProperty("processor", "mdc", "mq.host");
    private static  String PK_MQ_VIRTUAL_HOST = DWModulePropertiesUtils.getProperty("processor", "mdc", "mq.virtual.host");

    private static  String PK_MQ_EXCHANGE_NAME = DWModulePropertiesUtils.getProperty("processor", "mdc", "mq.exchange.name");
    private static  String PK_MQ_EXCHANGE_TYPE = DWModulePropertiesUtils.getProperty("processor", "mdc", "mq.exchange.type");
    private static  String PK_MQ_QUEUE_NAME = DWModulePropertiesUtils.getProperty("processor", "mdc", "mq.queue.name");
    private static  String PK_MQ_ROUTING_KEY = DWModulePropertiesUtils.getProperty("processor", "mdc", "mq.routing.key");
    private static  String PK_ERP_LIST = DWModulePropertiesUtils.getProperty("processor", "mdc", "erp.list");

    private static  String tRedisHost = DWModulePropertiesUtils.getProperty("processor", "mdc", "redis.host");
    private static  String tRedisDb = DWModulePropertiesUtils.getProperty("processor", "mdc", "redis.database");
    private static  String tRedisPort = DWModulePropertiesUtils.getProperty("processor", "mdc", "redis.port");
    private static  String tRedisPassword = DWModulePropertiesUtils.getProperty("processor", "mdc", "redis.password");

    /**
     * 默认失效时间1小时
     */
    private static  String TIME_OUT = DWApplicationConfigUtils.getProperty("time.out");

    /**
     * 默认随机数
     */
    private static  String TIME_RANDOM = DWApplicationConfigUtils.getProperty("time.random");

    /**
     * cac配置
     */
    private static  String PK_CAC_HOST = DWModulePropertiesUtils.getProperty("processor", "mdc", "cac.url");

    /**
     * eoc配置
     */
    private static  String PK_EOC_HOST = DWModulePropertiesUtils.getProperty("processor", "mdc", "eoc.url");

    /**
     * iam配置
     */
    private static  String PK_IAM_HOST = DWModulePropertiesUtils.getProperty("processor", "mdc", "iam.url");

    /**
     * Parameter Values
     */
    public static String _MQ_PORT;
    public static String _MQ_USERNAME;
    public static String _MQ_PASSWORD;
    public static String _MQ_HOST;
    public static String _MQ_VIRTUAL_HOST;

    public static String _MQ_EXCHANGE_NAME;
    public static String _MQ_EXCHANGE_TYPE;
    public static String _MQ_QUEUE_NAME;
    public static String _MQ_ROUTING_KEY;
    public static String _ERP_LIST;

    public static String _REDIS_HOST;
    public static String _REDIS_PORT;
    public static String _REDIS_PASSWORD;
    public static Integer _REDIS_DB;

    public static Long _TIME_OUT;
    public static int _TIME_RANDOM;

    public static String _CAC_HOST;

    public static String _EOC_HOST;

    public static String _IAM_HOST;

    /**
     * Constructor
     */
//    static  {
//        ApplicationParameter.loadParameters();
//    }

    /**
     * 開始設定參數
     */
    public  void loadParameters() {
        PK_MQ_PORT = MdcSpringContextUtil.getProperty("mq.port");
        PK_MQ_USERNAME = MdcSpringContextUtil.getProperty( "mq.username");
        PK_MQ_PASSWORD = MdcSpringContextUtil.getProperty( "mq.password");
        PK_MQ_HOST = MdcSpringContextUtil.getProperty( "mq.host");
        PK_MQ_VIRTUAL_HOST = MdcSpringContextUtil.getProperty( "mq.virtual.host");

        PK_MQ_EXCHANGE_NAME = MdcSpringContextUtil.getProperty( "mq.exchange.name");
        PK_MQ_EXCHANGE_TYPE = MdcSpringContextUtil.getProperty( "mq.exchange.type");
        PK_MQ_QUEUE_NAME = MdcSpringContextUtil.getProperty( "mq.queue.name");
        PK_MQ_ROUTING_KEY = MdcSpringContextUtil.getProperty( "mq.routing.key");
        PK_ERP_LIST = MdcSpringContextUtil.getProperty( "erp.list");

        tRedisHost = MdcSpringContextUtil.getProperty( "redis.host");
        tRedisDb = MdcSpringContextUtil.getProperty( "redis.database");
        tRedisPort = MdcSpringContextUtil.getProperty( "redis.port");
        tRedisPassword = MdcSpringContextUtil.getProperty( "redis.password");

        TIME_OUT = MdcSpringContextUtil.getProperty("time.out");

        TIME_RANDOM = MdcSpringContextUtil.getProperty("time.random");

        PK_CAC_HOST = MdcSpringContextUtil.getProperty( "cac.url");

        PK_EOC_HOST = MdcSpringContextUtil.getProperty( "eoc.url");

        PK_IAM_HOST = MdcSpringContextUtil.getProperty( "iam.url");


        _MQ_PORT = PK_MQ_PORT;
        _MQ_USERNAME = PK_MQ_USERNAME;
        _MQ_PASSWORD = PK_MQ_PASSWORD;
        _MQ_HOST = PK_MQ_HOST;
        _MQ_VIRTUAL_HOST = PK_MQ_VIRTUAL_HOST;

        _MQ_EXCHANGE_NAME = PK_MQ_EXCHANGE_NAME;
        _MQ_EXCHANGE_TYPE = PK_MQ_EXCHANGE_TYPE;
        _MQ_QUEUE_NAME = PK_MQ_QUEUE_NAME;
        _MQ_ROUTING_KEY = PK_MQ_ROUTING_KEY;
        _ERP_LIST = PK_ERP_LIST;

        _REDIS_HOST = tRedisHost;
        _REDIS_DB = Integer.parseInt(tRedisDb);
        _REDIS_PORT = tRedisPort;
        _REDIS_PASSWORD = tRedisPassword;

        _TIME_OUT = null == TIME_OUT ? MdcConstant.TIME_OUT : Long.parseLong(TIME_OUT);
        _TIME_RANDOM = null == TIME_OUT ? MdcConstant.TIME_RANDOM : Integer.parseInt(TIME_RANDOM);

        _CAC_HOST = PK_CAC_HOST;

        _EOC_HOST = PK_EOC_HOST;

        _IAM_HOST = PK_IAM_HOST;
    }

    @Override
    public void afterPropertiesSet() throws Exception {
        loadParameters();
    }

    @Override
    public void setApplicationContext(ApplicationContext applicationContext) throws BeansException {
        MdcSpringContextUtil.context = applicationContext;
    }
}

==> mdc-1.0-20250827.035906-4-sources.jar: com/digiwin/metadatacache/MdcApplicationParameter.java <==
package com.digiwin.metadatacache;

import com.digiwin.app.common.DWApplicationConfigUtils;
import com.digiwin.app.module.DWModulePropertiesUtils;
import com.digiwin.metadatacache.constant.MdcConstant;
import com.digiwin.metadatacache.util.MdcSpringContextUtil;
import org.springframework.beans.BeansException;
import org.springframework.beans.factory.InitializingBean;
import org.springframework.context.ApplicationContext;
import org.springframework.context.ApplicationContextAware;
import org.springframework.stereotype.Component;

/**
 * 配置获取
 */
@Component("mdcApplicationParameter")
public class MdcApplicationParameter implements InitializingBean, ApplicationContextAware {

    /**
     * the value keys in the property file
     */
    private static  String PK_MQ_PORT = DWModulePropertiesUtils.getProperty("processor", "mdc", "mq.port");
    private static  String PK_MQ_USERNAME = DWModulePropertiesUtils.getProperty("processor", "mdc", "mq.username");
    private static  String PK_MQ_PASSWORD = DWModulePropertiesUtils.getProperty("processor", "mdc", "mq.password");
    private static  String PK_MQ_HOST = DWModulePropertiesUtils.getProperty("processor", "mdc", "mq.host");
    private static  String PK_MQ_VIRTUAL_HOST = DWModulePropertiesUtils.getProperty("processor", "mdc", "mq.virtual.host");

    private static  String PK_MQ_EXCHANGE_NAME = DWModulePropertiesUtils.getProperty("processor", "mdc", "mq.exchange.name");
    private static  String PK_MQ_EXCHANGE_TYPE = DWModulePropertiesUtils.getProperty("processor", "mdc", "mq.exchange.type");
    private static  String PK_MQ_QUEUE_NAME = DWModulePropertiesUtils.getProperty("processor", "mdc", "mq.queue.name");
    private static  String PK_MQ_ROUTING_KEY = DWModulePropertiesUtils.getProperty("processor", "mdc", "mq.routing.key");
    private static  String PK_ERP_LIST = DWModulePropertiesUtils.getProperty("processor", "mdc", "erp.list");

    private static  String tRedisHost = DWModulePropertiesUtils.getProperty("processor", "mdc", "spring.redis.host");
    private static  String tRedisDb = DWModulePropertiesUtils.getProperty("processor", "mdc", "spring.redis.database");
    private static  String tRedisPort = DWModulePropertiesUtils.getProperty("processor", "mdc", "spring.redis.port");
    private static  String tRedisPassword = DWModulePropertiesUtils.getProperty("processor", "mdc", "spring.redis.password");

    /**
     * 默认失效时间1小时
     */
    private static  String TIME_OUT = DWApplicationConfigUtils.getProperty("time.out");

    /**
     * 默认随机数
     */
    private static  String TIME_RANDOM = DWApplicationConfigUtils.getProperty("time.random");

    /**
     * cac配置
     */
    private static  String PK_CAC_HOST = DWModulePropertiesUtils.getProperty("processor", "mdc", "cacUrl");

    /**
     * eoc配置
     */
    private static  String PK_EOC_HOST = DWModulePropertiesUtils.getProperty("processor", "mdc", "eocUrl");

    /**
     * iam配置
     */
    private static  String PK_IAM_HOST = DWModulePropertiesUtils.getProperty("processor", "mdc", "iamUrl");

    /**
     * Parameter Values
     */
    public static String _MQ_PORT;
    public static String _MQ_USERNAME;
    public static String _MQ_PASSWORD;
    public static String _MQ_HOST;
    public static String _MQ_VIRTUAL_HOST;

    public static String _MQ_EXCHANGE_NAME;
    public static String _MQ_EXCHANGE_TYPE;
    public static String _MQ_QUEUE_NAME;
    public static String _MQ_ROUTING_KEY;
    public static String _ERP_LIST;

    public static String _REDIS_HOST;
    public static String _REDIS_PORT;
    public static String _REDIS_PASSWORD;
    public static Integer _REDIS_DB;

    public static Long _TIME_OUT;
    public static int _TIME_RANDOM;

    public static String _CAC_HOST;

    public static String _EOC_HOST;

    public static String _IAM_HOST;

    /**
     * Constructor
     */
//    static  {
//        ApplicationParameter.loadParameters();
//    }

    /**
     * 開始設定參數
     */
    public  void loadParameters() {
        PK_MQ_PORT = MdcSpringContextUtil.getProperty("mq.port");
        PK_MQ_USERNAME = MdcSpringContextUtil.getProperty( "mq.username");
        PK_MQ_PASSWORD = MdcSpringContextUtil.getProperty( "mq.password");
        PK_MQ_HOST = MdcSpringContextUtil.getProperty( "mq.host");
        PK_MQ_VIRTUAL_HOST = MdcSpringContextUtil.getProperty( "mq.virtual.host");

        PK_MQ_EXCHANGE_NAME = MdcSpringContextUtil.getProperty( "mq.exchange.name");
        PK_MQ_EXCHANGE_TYPE = MdcSpringContextUtil.getProperty( "mq.exchange.type");
        PK_MQ_QUEUE_NAME = MdcSpringContextUtil.getProperty( "mq.queue.name");
        PK_MQ_ROUTING_KEY = MdcSpringContextUtil.getProperty( "mq.routing.key");
        PK_ERP_LIST = MdcSpringContextUtil.getProperty( "erp.list");

        tRedisHost = MdcSpringContextUtil.getProperty( "spring.redis.host");
        tRedisDb = MdcSpringContextUtil.getProperty( "spring.redis.database");
        tRedisPort = MdcSpringContextUtil.getProperty( "spring.redis.port");
        tRedisPassword = MdcSpringContextUtil.getProperty( "spring.redis.password");

        TIME_OUT = MdcSpringContextUtil.getProperty("time.out");

        TIME_RANDOM = MdcSpringContextUtil.getProperty("time.random");

        PK_CAC_HOST = MdcSpringContextUtil.getProperty( "cacUrl");

        PK_EOC_HOST = MdcSpringContextUtil.getProperty( "eocUrl");

        PK_IAM_HOST = MdcSpringContextUtil.getProperty( "iamUrl");


        _MQ_PORT = PK_MQ_PORT;
        _MQ_USERNAME = PK_MQ_USERNAME;
        _MQ_PASSWORD = PK_MQ_PASSWORD;
        _MQ_HOST = PK_MQ_HOST;
        _MQ_VIRTUAL_HOST = PK_MQ_VIRTUAL_HOST;

        _MQ_EXCHANGE_NAME = PK_MQ_EXCHANGE_NAME;
        _MQ_EXCHANGE_TYPE = PK_MQ_EXCHANGE_TYPE;
        _MQ_QUEUE_NAME = PK_MQ_QUEUE_NAME;
        _MQ_ROUTING_KEY = PK_MQ_ROUTING_KEY;
        _ERP_LIST = PK_ERP_LIST;

        _REDIS_HOST = tRedisHost;
        _REDIS_DB = 0;
        if(null!=tRedisDb){
            _REDIS_DB = Integer.parseInt(tRedisDb);
        }
        _REDIS_PORT = tRedisPort;
        _REDIS_PASSWORD = tRedisPassword;

        _TIME_OUT = null == TIME_OUT ? MdcConstant.TIME_OUT : Long.parseLong(TIME_OUT);
        _TIME_RANDOM = null == TIME_OUT ? MdcConstant.TIME_RANDOM : Integer.parseInt(TIME_RANDOM);

        _CAC_HOST = PK_CAC_HOST;

        _EOC_HOST = PK_EOC_HOST;

        _IAM_HOST = PK_IAM_HOST;
    }

    @Override
    public void afterPropertiesSet() throws Exception {
        loadParameters();
    }

    @Override
    public void setApplicationContext(ApplicationContext applicationContext) throws BeansException {
        MdcSpringContextUtil.context = applicationContext;
    }
}
